@@ -39,7 +39,8 @@ from matplotlib import pyplot as plt
 @click.argument("out_dir", type=click.Path(dir_okay=True))
 @click.option("--chunks", default=100, help="Number of chunks to load in memory.")
 @click.option("--channel-means-only", is_flag=True, show_default=True, default=False)
-def preprocess(raw_path, out_dir, chunks=100, channel_means_only=False):
+@click.option("--crop", default=0)
+def preprocess(raw_path, out_dir, chunks=100, channel_means_only=False, crop=0):
     """Preprocessing to extract deltaF from a single session.
 
     Preprocessing separates the two channels, applies the haemodynamic correction,
@@ -76,7 +77,7 @@ def preprocess(raw_path, out_dir, chunks=100, channel_means_only=False):
         d.shape[1] // (d.shape[1] / 2),
         d.shape[2] / 2,
         d.shape[2] // (d.shape[2] / 2),
-    ).mean(axis=(-1, 1, 3))
+    ).mean(axis=(-1, 1, 3))[:, crop:-crop, crop:-crop]
     click.echo("2x2 binning to shape {}".format(raw_frames.shape))
 
     # Channel separation
